@@ -45,12 +45,12 @@
 #' mat<-NUC2Binary_RNA(seqs = fileLNC,outFormat="mat")
 #'
 #' ad<-paste0(dir,"/NUC2Binary.txt")
-#' NUC2Binary_RNA(seqs = fileLNC,binaryType="strBin",outFormat="txt",outputFileDist=ad)
+#' NUC2Binary_RNA(seqs = fileLNC,binaryType="numBin",outFormat="txt",outputFileDist=ad)
 #'
 #' unlink("dir", recursive = TRUE)
 
 
-NUC2Binary_RNA <- function(seqs,binaryType="strBin",label=c(),outFormat="mat",outputFileDist="")
+NUC2Binary_RNA <- function(seqs,binaryType="numBin",label=c(),outFormat="mat",outputFileDist="")
 {
 
 
